# YetAnotherPicSearch

基于 [nonebot/nonebot2](https://github.com/nonebot/nonebot2) 及 [kitUIN/PicImageSearch](https://github.com/kitUIN/PicImageSearch) 的另一个 Nonebot 搜图插件。

目前适配的是 `OneBot V11` ，没适配 QQ 频道。

主要受到 [Tsuk1ko/cq-picsearcher-bot](https://github.com/Tsuk1ko/cq-picsearcher-bot) 的启发。 而我只需要基础的搜图功能，于是忍不住自己也写了一个。

目前支持的搜图服务：

- [saucenao](https://saucenao.com)
- [whatanime](https://trace.moe)
- [ascii2d](https://ascii2d.net)
- [exhentai](https://exhentai.org)

详细说明请移步：[docs](docs)

## 感谢以下项目或服务（不分先后）

- [saucenao](https://saucenao.com)
- [ascii2d](https://ascii2d.net)
- [trace.moe](https://trace.moe) ([GitHub](https://github.com/soruly/trace.moe))
- [exhentai](https://exhentai.org)
- [cq-picsearcher-bot](https://github.com/Tsuk1ko/cq-picsearcher-bot)
- [PicImageSearch](https://github.com/kitUIN/PicImageSearch)
